@@ -5,7 +5,7 @@ import click
 from click_plugins import with_plugins
 from pkg_resources import iter_entry_points, resource_filename
 
-from magnus import defaults, pipeline
+from magnus import defaults, docker_utils, pipeline
 
 fileConfig(resource_filename(__name__, 'log_config.ini'))
 logger = logging.getLogger(defaults.NAME)
@@ -61,7 +61,7 @@ def execute(file, var_file, config_file, parameters_file, log_level, tag, run_id
 @click.option('--tag', help='A tag attached to the run')
 @click.option('--run-id', help='An optional run_id, one would be generated if not provided')
 @click.option('--use-cached', help='Provide the previous run_id to re-run.', show_default=True)
-def execute_single_step(step_name, file, var_file, config_file, parameters_file, log_level, tag, run_id, use_cached):  # pragma: no cover
+def execute_step(step_name, file, var_file, config_file, parameters_file, log_level, tag, run_id, use_cached):  # pragma: no cover
     """
     Entry point to executing a single step of the pipeline.
 
@@ -117,3 +117,32 @@ def execute_single_branch(run_id, branch_name, map_variable, file, var_file, con
     pipeline.execute_single_brach(variables_file=var_file, configuration_file=config_file,
                                   pipeline_file=file, branch_name=branch_name, map_variable=map_variable,
                                   run_id=run_id)
+
+
+@cli.command('build_docker', short_help="Utility tool to build docker images")
+@click.argument('image_name')
+@click.option('-f', '--docker-file', default=None, help="The dockerfile to be used. If None, we generate one")
+@click.option('-s', '--style', default="poetry", help="The method used to get requirements", show_default=True)
+@click.option('-t', "--tag", default="latest", help="The tag assigned to the image", show_default=True)
+@click.option('-c', '--commit-tag', is_flag=True, default=False, help="Use commit id as tag. Over-rides tag option",
+              show_default=True)
+@click.option('-d', '--dry-run', is_flag=True, default=False, help="Generate the dockerfile, but NOT the image",
+              show_default=True)
+@click.option('--git-tracked/--all', default=True, help="Controls what should be added to image. All vs git-tracked",
+              show_default=True)
+def build_docker(image_name, docker_file, style, tag, commit_tag, dry_run, git_tracked):
+    """
+    A utility function to create docker images from the existing codebase.
+
+    It is advised to provide your own dockerfile as much as possible. If you do not have one handy, you can use
+    --dry-run functionality to see if the auto-generated one suits your needs.
+
+    If you are auto-generating the dockerfile:
+    BEWARE!! Over-riding the default options assumes you know what you are doing! BEWARE!!
+
+    1). By default, only git tracked files are added to the docker image.
+
+    2). The auto-generated dockerfile uses, python 3.7 as the default image and adds the current folder.
+    """
+    docker_utils.build_docker(image_name=image_name, docker_file=docker_file, style=style,
+                              tag=tag, commit_tag=commit_tag, dry_run=dry_run, git_tracked=git_tracked)
